@@ -226,7 +226,7 @@ def define_new_opts():
 		"help" : "-d, --devices=[devices]        List of devices to use for current operation",
 		"required" : "0",
 		"shortdesc" : "List of devices to use for current operation. Devices can \
-be comma-separated list of device-mapper multipath devices (eg. /dev/mapper/3600508b400105df70000e00000ac0000 or /dev/mapper/mpath1). \
+be comma or space separated list of device-mapper multipath devices (eg. /dev/mapper/3600508b400105df70000e00000ac0000 or /dev/mapper/mpath1). \
 Each device must support SCSI-3 persistent reservations.",
 		"order": 1
 	}
@@ -304,7 +304,7 @@ be removed from the device(s)."
 
 	docs = {}
 	docs["shortdesc"] = "Fence agent for multipath persistent reservation"
-	docs["longdesc"] = "fence_mpath is an I/O fencing agent that uses SCSI-3 \
+	docs["longdesc"] = "fence_mpath is an I/O Fencing agent that uses SCSI-3 \
 persistent reservations to control access multipath devices. Underlying \
 devices must support SCSI-3 persistent reservations (SPC-3 or greater) as \
 well as the \"preempt-and-abort\" subcommand.\nThe fence_mpath agent works by \
@@ -331,7 +331,7 @@ failing."
 	if not ("--devices" in options and options["--devices"]):
 		fail_usage("Failed: No devices found")
 
-	options["devices"] = [d for d in re.split("\s*,\s*|\s+", options["--devices"].strip()) if d]
+	options["devices"] = [d for d in re.split(r"\s*,\s*|\s+", options["--devices"].strip()) if d]
 	# Input control END
 
 	result = fence_action(None, options, set_status, get_status)
